/*
 * Copyright (C) 2020-2021 David Sugar <tychosoft@gmail.com>.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "driver.hpp"
#include "extend.hpp"

#include <strings.hpp>

using namespace server;

auto extend::scr_notify() noexcept -> bool
{
    auto to = syms.get_value("CALLER");
    auto subject = "";
    while(auto opt = option()) {
        auto val = value();
        if(!val)
            return error("missing value");
        if(eq(opt, "to"))
            to = val;
        else if(eq(opt, "subject"))
            subject = val;
    }

    char buffer[160];
    buffer[0] = 0;
    while(auto v = value())
        mem_append(buffer, sizeof(buffer), v);

    coventry_driver::notify(to, buffer, subject);
    skip();
    return false;
}

auto checks::chk_notify(const script::context_t& ctx) -> const char *
{
    if(ctx.header && eq(ctx.header->id, "_init_"))
        return "notify cannot be used to initialize";

    unsigned index = 0;
    const char *cp = nullptr;
    while(nullptr != (cp = ctx.line->argv[index])) {
        if(*cp != '=')
            break;
        cp = ctx.line->argv[++index];
        if(!cp)
            return "notify option missing";
        ++index;
    }

    if(!ctx.line->argv[index]) {
        return "notify text missing";
    }
    return nullptr;
}
