/*
 * Copyright 2020-2021 David Sugar, Tycho Softworks.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "driver.hpp"
#include "sessions.hpp"
#include "logger.hpp"

#include <keyfile.hpp>

#include <csignal>

#include <unistd.h>

using namespace server;

test_driver test_driver::instance;

test_driver::test_driver() : Driver("test")
{
}

void test_driver::startup([[maybe_unused]] const keyfile& config)
{
    kill(getpid(), SIGHUP);
}

void test_driver::restart(const keyfile& config)
{
    int exit_code = 0;
    if(unit_tests(config) > 0)
        exit_code = 99;
    ::exit(exit_code);
}

void test_driver::shutdown()
{
}

void test_driver::drop(Session *session)
{
    debug(4, "sid({}): detected session drop", session->sid());
}

#ifdef BUILD_STATIC
extern Driver *loader::bind_driver()
{
    return &test_driver::instance;
}
#endif
